import type { AxiosInstance } from "axios";
import type { Region, Locale } from "@valapi/lib";
import type { Config as AuthConfig, PromiseResponse } from "@valapi/auth";
import { WebClientRegionURL } from "./WebClientRegionURL";
import { AccountXP } from "../service/AccountXP";
import { Configuration } from "../service/Configuration";
import { Content } from "../service/Content";
import { ContractDefinitions } from "../service/ContractDefinitions";
import { Contracts } from "../service/Contracts";
import { CoreGame } from "../service/CoreGame";
import { DailyTicket } from "../service/DailyTicket";
import { Favorites } from "../service/Favorites";
import { Latency } from "../service/Latency";
import { MassRewards } from "../service/MassRewards";
import { Match } from "../service/Match";
import { MMR } from "../service/MMR";
import { NameService } from "../service/NameService";
import { Party } from "../service/Party";
import { Personalization } from "../service/Personalization";
import { PreGame } from "../service/PreGame";
import { Premier } from "../service/Premier";
import { Restrictions } from "../service/Restrictions";
import { Session } from "../service/Session";
import { Store } from "../service/Store";
export interface Config extends Omit<AuthConfig, "user"> {
    user: NonNullable<AuthConfig["user"]>;
    region: Region.ID;
}
export interface UserInfoResponse {
    country: string;
    sub: string;
    email_verified: boolean;
    player_plocale: any;
    country_at: number;
    pw: {
        cng_at: number;
        reset: boolean;
        must_reset: boolean;
    };
    phone_number_verified: boolean;
    account_verified: boolean;
    ppid: any;
    federated_identity_details: Array<{
        provider_name: string;
        provider_environment: any;
    }>;
    federated_identity_providers: Array<string>;
    player_locale: Locale.ID;
    acct: {
        type: number;
        state: string;
        adm: boolean;
        game_name: string;
        tag_line: string;
        created_at: number;
    };
    age: number;
    jti: string;
    affinity: Record<string, string>;
}
/**
 * API from Web Client
 */
export declare class WebClient {
    protected readonly request: AxiosInstance;
    protected readonly regionURL: WebClientRegionURL;
    readonly subject: string;
    constructor(config: Config);
    getUserInfo(): PromiseResponse<UserInfoResponse>;
    /**
     * @deprecated Please, Contact us if you find out how its works
     */
    getUserSettings(): PromiseResponse<any>;
    /**
     * @deprecated Please, Contact us if you find out how its works
     */
    updateUserSettings(data: any): PromiseResponse<any>;
    get AccountXP(): AccountXP;
    get Configuration(): Configuration;
    get Content(): Content;
    get ContractDefinitions(): ContractDefinitions;
    get Contracts(): Contracts;
    get CoreGame(): CoreGame;
    get DailyTicket(): DailyTicket;
    get Favorites(): Favorites;
    get Latency(): Latency;
    get MassRewards(): MassRewards;
    get Match(): Match;
    get MMR(): MMR;
    get NameService(): NameService;
    get Party(): Party;
    get Personalization(): Personalization;
    get PreGame(): PreGame;
    get Premier(): Premier;
    get Restrictions(): Restrictions;
    get Session(): Session;
    get Store(): Store;
}
