"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebClient = void 0;
const lib_1 = require("@valapi/lib");
const auth_1 = require("@valapi/auth");
const WebClientRegionURL_1 = require("./WebClientRegionURL");
const AccountXP_1 = require("../service/AccountXP");
const Configuration_1 = require("../service/Configuration");
const Content_1 = require("../service/Content");
const ContractDefinitions_1 = require("../service/ContractDefinitions");
const Contracts_1 = require("../service/Contracts");
const CoreGame_1 = require("../service/CoreGame");
const DailyTicket_1 = require("../service/DailyTicket");
const Favorites_1 = require("../service/Favorites");
const Latency_1 = require("../service/Latency");
const MassRewards_1 = require("../service/MassRewards");
const Match_1 = require("../service/Match");
const MMR_1 = require("../service/MMR");
const NameService_1 = require("../service/NameService");
const Party_1 = require("../service/Party");
const Personalization_1 = require("../service/Personalization");
const PreGame_1 = require("../service/PreGame");
const Premier_1 = require("../service/Premier");
const Restrictions_1 = require("../service/Restrictions");
const Session_1 = require("../service/Session");
const Store_1 = require("../service/Store");
/**
 * API from Web Client
 */
class WebClient {
    constructor(config) {
        const auth = new auth_1.Auth(config);
        if (!auth.isAuthenticated) {
            throw new lib_1.ValError({
                name: "WebClient_Constructor_Error",
                message: `user is not authenticated`,
                data: config.user
            });
        }
        this.request = auth.request.create();
        this.regionURL = new WebClientRegionURL_1.WebClientRegionURL(config.region);
        this.subject = auth.subject;
    }
    getUserInfo() {
        return this.request.post(`https://auth.riotgames.com/userinfo`);
    }
    /**
     * @deprecated Please, Contact us if you find out how its works
     */
    getUserSettings() {
        return this.request.get(`https://playerpreferences.riotgames.com/playerPref/v3/getPreference/Ares.PlayerSettings`);
    }
    /**
     * @deprecated Please, Contact us if you find out how its works
     */
    updateUserSettings(data) {
        return this.request.put(`https://playerpreferences.riotgames.com/playerPref/v3/getPreference`, {
            type: "Ares.PlayerSettings",
            data: data
        });
    }
    get AccountXP() {
        return new AccountXP_1.AccountXP(this.request, this.regionURL);
    }
    get Configuration() {
        return new Configuration_1.Configuration(this.request, this.regionURL);
    }
    get Content() {
        return new Content_1.Content(this.request, this.regionURL);
    }
    get ContractDefinitions() {
        return new ContractDefinitions_1.ContractDefinitions(this.request, this.regionURL);
    }
    get Contracts() {
        return new Contracts_1.Contracts(this.request, this.regionURL);
    }
    get CoreGame() {
        return new CoreGame_1.CoreGame(this.request, this.regionURL);
    }
    get DailyTicket() {
        return new DailyTicket_1.DailyTicket(this.request, this.regionURL);
    }
    get Favorites() {
        return new Favorites_1.Favorites(this.request, this.regionURL);
    }
    get Latency() {
        return new Latency_1.Latency(this.request, this.regionURL);
    }
    get MassRewards() {
        return new MassRewards_1.MassRewards(this.request, this.regionURL);
    }
    get Match() {
        return new Match_1.Match(this.request, this.regionURL);
    }
    get MMR() {
        return new MMR_1.MMR(this.request, this.regionURL);
    }
    get NameService() {
        return new NameService_1.NameService(this.request, this.regionURL);
    }
    get Party() {
        return new Party_1.Party(this.request, this.regionURL);
    }
    get Personalization() {
        return new Personalization_1.Personalization(this.request, this.regionURL);
    }
    get PreGame() {
        return new PreGame_1.PreGame(this.request, this.regionURL);
    }
    get Premier() {
        return new Premier_1.Premier(this.request, this.regionURL);
    }
    get Restrictions() {
        return new Restrictions_1.Restrictions(this.request, this.regionURL);
    }
    get Session() {
        return new Session_1.Session(this.request, this.regionURL);
    }
    get Store() {
        return new Store_1.Store(this.request, this.regionURL);
    }
}
exports.WebClient = WebClient;
