import type { PromiseResponse } from "@valapi/auth";
import { WebClientService } from "../client/WebClientService";
export declare namespace CoreGame {
    interface Player {
        Subject: string;
        MatchID: string;
        Version: number;
    }
    interface Match {
        MatchID: string;
        Version: number;
        State: string;
        MapID: string;
        ModeID: string;
        ProvisioningFlow: string;
        GamePodID: string;
        AllMUCName: string;
        TeamMUCName: string;
        TeamVoiceID: string;
        TeamMatchToken: string;
        IsReconnectable: boolean;
        ConnectionDetails: {
            GameServerHosts: Array<string>;
            GameServerHost: string;
            GameServerPort: number;
            GameServerObfuscatedIP: number;
            GameClientHash: number;
            PlayerKey: string;
        };
        PostGameDetails: {
            Start: Date;
            Players: Array<{
                Subject: string;
            }>;
        };
        Players: Array<{
            Subject: string;
            TeamID: string;
            CharacterID: string;
            PlayerIdentity: {
                Subject: string;
                PlayerCardID: string;
                PlayerTitleID: string;
                AccountLevel: number;
                PreferredLevelBorderID: string;
                Incognito: boolean;
                HideAccountLevel: boolean;
            };
            SeasonalBadgeInfo: {
                SeasonID: string;
                NumberOfWins: number;
                WinsByTier: any;
                Rank: number;
                LeaderboardRank: number;
            };
            IsCoach: boolean;
            IsAssociated: boolean;
        }>;
        MatchmakingData: {
            QueueID: string;
            IsRanked: boolean;
        };
    }
    interface Loadout {
        Loadouts: Array<{
            CharacterID: string;
            Loadout: {
                Subject: string;
                Sprays: {
                    SpraySelections: Array<{
                        SocketID: string;
                        SprayID: string;
                        LevelID: string;
                    }>;
                };
                Expressions: {
                    AESSelections: Array<{
                        SocketID: string;
                        AssetID: string;
                        TypeID: string;
                    }>;
                };
                Items: Record<string, {
                    ID: string;
                    TypeID: string;
                    Sockets: Record<string, {
                        ID: string;
                        Item: {
                            ID: string;
                            TypeID: string;
                        };
                    }>;
                }>;
            };
        }>;
    }
}
/**
 * Current Game
 */
export declare class CoreGame extends WebClientService {
    fetchPlayer(subject: string): PromiseResponse<CoreGame.Player>;
    fetchMatch(matchId: string): PromiseResponse<CoreGame.Match>;
    fetchMatchLoadouts(matchId: string): PromiseResponse<CoreGame.Loadout>;
    /**
     * ! Careful to use, Riot will immediately shut down your Project.
     */
    disassociatePlayer(subject: string, matchId: string): PromiseResponse<any>;
    /**
     * @deprecated Please, Contact us if you find out how its works
     */
    fetchAllChatMUCToken(matchId: string): PromiseResponse<any>;
    /**
     * @deprecated Please, Contact us if you find out how its works
     */
    fetchTeamChatMUCToken(matchId: string): PromiseResponse<any>;
    /**
     * @deprecated Please, Contact us if you find out how its works
     */
    fetchVoiceToken(matchId: string): PromiseResponse<any>;
}
