"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PartyCode = exports.CustomGame = exports.Player = exports.MatchMaking = exports.Party = void 0;
const WebClientService_1 = require("../client/WebClientService");
class Party extends WebClientService_1.WebClientService {
    refreshCompetitiveTier(subject, partyId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/members/${subject}/refreshCompetitiveTier`);
    }
    refreshPlayerIdentity(subject, partyId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/members/${subject}/refreshPlayerIdentity`);
    }
    refreshPings(subject, partyId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/members/${subject}/refreshPings`);
    }
    get(partyId) {
        return this.request.get(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}`);
    }
    getMUCToken(partyId) {
        return this.request.get(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/muctoken`);
    }
    getVoiceToken(partyId) {
        return this.request.get(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/voicetoken`);
    }
    setAccessibility(partyId, accessibility) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/accessibility`, {
            accessibility: accessibility
        });
    }
    inviteByDisplayName(partyId, gameName, tagLine) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/invites/name/${gameName}/tag/${tagLine}`);
    }
    declineJoinRequest(partyId, requestId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/request/${requestId}/decline`);
    }
    get MatchMaking() {
        return new MatchMaking(this.request, this.regionURL);
    }
    get Player() {
        return new Player(this.request, this.regionURL);
    }
    get CustomGame() {
        return new CustomGame(this.request, this.regionURL);
    }
    get PartyCode() {
        return new PartyCode(this.request, this.regionURL);
    }
}
exports.Party = Party;
class MatchMaking extends WebClientService_1.WebClientService {
    /**
     * @param queueId Queue (EligibleQueues)
     */
    changeQueue(partyId, queueId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/queue`, {
            queueID: queueId
        });
    }
    makeDefaultQueue(partyId, queueId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/makedefault?queueID=${queueId}`);
    }
    /**
     * ! Careful to use, Riot will immediately shut down your Project.
     * @deprecated Please, Contact us if you find out how its works
     */
    startSoloExperience(subject) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/players/${subject}/startsoloexperience`);
    }
    start(partyId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/matchmaking/join`);
    }
    leave(partyId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/matchmaking/leave`);
    }
}
exports.MatchMaking = MatchMaking;
class Player extends WebClientService_1.WebClientService {
    get(subject) {
        return this.request.get(`${this.regionURL.url.partyService}/parties/v1/players/${subject}`);
    }
    remove(subject) {
        return this.request.delete(`${this.regionURL.url.partyService}/parties/v1/players/${subject}`);
    }
    joinParty(subject, partyId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/players/${subject}/joinparty/${partyId}`);
    }
    leaveParty(subject, partyId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/players/${subject}/leaveparty/${partyId}`);
    }
    setReady(subject, partyId, isReady) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/members/${subject}/setReady`, {
            ready: isReady
        });
    }
    leaveFromParty(subject, partyId) {
        return this.request.delete(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/members/${subject}`);
    }
    transferOwner(subject, partyId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/members/${subject}/owner`);
    }
}
exports.Player = Player;
class CustomGame extends WebClientService_1.WebClientService {
    makeInto(partyId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/makecustomgame`);
    }
    start(partyId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/startcustomgame`);
    }
    changeSettings(partyId, settings) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/customgamesettings`, settings);
    }
    changeTeam(partyId, team, subject) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/customgamemembership/${team}`, {
            playerToPutOnTeam: subject
        });
    }
    setBalance(partyId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/balance`);
    }
    getConfig() {
        return this.request.get(`${this.regionURL.url.partyService}/parties/v1/parties/customgameconfigs`);
    }
}
exports.CustomGame = CustomGame;
class PartyCode extends WebClientService_1.WebClientService {
    create(partyId) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/invitecode`);
    }
    delete(partyId) {
        return this.request.delete(`${this.regionURL.url.partyService}/parties/v1/parties/${partyId}/invitecode`);
    }
    join(partyCode) {
        return this.request.post(`${this.regionURL.url.partyService}/parties/v1/players/joinbycode/${partyCode}`);
    }
}
exports.PartyCode = PartyCode;
