import type { PromiseResponse } from "@valapi/auth";
import { WebClientService } from "../client/WebClientService";
export declare namespace PreGame {
    interface Player {
        Subject: string;
        MatchID: string;
        Version: number;
    }
    interface PlayerInfo {
        Subject: string;
        CharacterID: string;
        CharacterSelectionState: string;
        PregamePlayerState: string;
        CompetitiveTier: number;
        PlayerIdentity: {
            Subject: string;
            PlayerCardID: string;
            PlayerTitleID: string;
            AccountLevel: number;
            PreferredLevelBorderID: string;
            Incognito: boolean;
            HideAccountLevel: boolean;
        };
        SeasonalBadgeInfo: {
            SeasonID: string;
            NumberOfWins: number;
            WinsByTier: any;
            Rank: number;
            LeaderboardRank: number;
        };
        IsCaptain: boolean;
    }
    interface Team {
        TeamID: string;
        Players: Array<PreGame.PlayerInfo>;
    }
    interface Match {
        ID: string;
        Version: number;
        Teams: Array<PreGame.Team>;
        AllyTeam: PreGame.Team;
        EnemyTeam: any;
        ObserverSubjects: Array<any>;
        MatchCoaches: Array<any>;
        EnemyTeamSize: number;
        EnemyTeamLockCount: number;
        PregameState: string;
        LastUpdated: Date;
        MapID: string;
        MapSelectPool: Array<any>;
        BannedMapIDs: Array<any>;
        CastedVotes: any;
        MapSelectSteps: Array<any>;
        MapSelectStep: number;
        Team1: string;
        GamePodID: string;
        Mode: string;
        VoiceSessionID: string;
        MUCName: string;
        TeamMatchToken: string;
        QueueID: string;
        ProvisioningFlowID: string;
        IsRanked: boolean;
        PhaseTimeRemainingNS: number;
        StepTimeRemainingNS: number;
        altModesFlagADA: boolean;
        TournamentMetadata: any;
        RosterMetadata: any;
    }
    interface Loadout {
        Loadouts: [
            {
                Subject: string;
                Sprays: {
                    SpraySelections: Array<{
                        SocketID: string;
                        SprayID: string;
                        LevelID: string;
                    }>;
                };
                Expressions: {
                    AESSelections: Array<{
                        SocketID: string;
                        AssetID: string;
                        TypeID: string;
                    }>;
                };
                Items: Record<string, {
                    ID: string;
                    TypeID: string;
                    Sockets: Record<string, {
                        ID: string;
                        Item: {
                            ID: string;
                            TypeID: string;
                        };
                    }>;
                }>;
            }
        ];
        LoadoutsValid: boolean;
    }
}
export declare class PreGame extends WebClientService {
    getPlayer(subject: string): PromiseResponse<PreGame.Player>;
    getMatch(matchId: string): PromiseResponse<PreGame.Match>;
    getMatchLoadouts(matchId: string): PromiseResponse<PreGame.Loadout>;
    /**
     * ! Careful to use, Riot will immediately shut down your Project.
     */
    selectCharacter(matchId: string, agentId: string): PromiseResponse<PreGame.Match>;
    /**
     * ! Careful to use, Riot will immediately shut down your Project.
     */
    lockCharacter(matchId: string, agentId: string): PromiseResponse<PreGame.Match>;
    /**
     * @deprecated Please, Contact us if you find out how its works
     */
    fetchVoiceToken(matchId: string): PromiseResponse<any>;
    /**
     * @deprecated Please, Contact us if you find out how its works
     */
    fetchChatToken(matchId: string): PromiseResponse<any>;
    /**
     * ! Careful to use, Riot will immediately shut down your Project.
     */
    quitMatch(matchId: string): PromiseResponse<any>;
}
