import type { ItemTypeId } from "@valapi/lib";
import type { PromiseResponse } from "@valapi/auth";
import { WebClientService } from "../client/WebClientService";
export declare namespace Store {
    type Currency = Record<string, number>;
    interface Wallet {
        Balances: Store.Currency;
        CurrencyLimits: Record<string, {
            Limits: Record<string, {
                amount: number;
                limitType: string;
            }>;
        }>;
    }
    interface Offer {
        OfferID: string;
        IsDirectPurchase: boolean;
        StartDate: Date;
        Cost: Store.Currency;
        Rewards: Array<{
            ItemTypeID: string;
            ItemID: string;
            Quantity: number;
        }>;
    }
    type UpgradeCurrencyOffers = Array<{
        OfferID: string;
        StorefrontItemID: string;
        Offer: Store.Offer;
        DiscountedPercent: number;
    }>;
    interface Bundle {
        ID: string;
        DataAssetID: string;
        CurrencyID: string;
        Items: Array<{
            Item: {
                ItemTypeID: string;
                ItemID: string;
                Amount: number;
            };
            BasePrice: number;
            CurrencyID: string;
            DiscountPercent: number;
            DiscountedPrice: number;
            IsPromoItem: boolean;
        }>;
        ItemOffers: Array<{
            BundleItemOfferID: string;
            Offer: Store.Offer;
            DiscountPercent: number;
            DiscountedCost: Store.Currency;
        }>;
        TotalBaseCost: Store.Currency;
        TotalDiscountedCost: Store.Currency;
        TotalDiscountPercent: number;
        DurationRemainingInSeconds: number;
        WholesaleOnly: boolean;
    }
    interface Storefront {
        FeaturedBundle: {
            Bundle: Store.Bundle;
            Bundles: Array<Store.Bundle>;
            BundleRemainingDurationInSeconds: number;
        };
        SkinsPanelLayout: {
            SingleItemOffers: Array<string>;
            SingleItemStoreOffers: Array<Store.Offer>;
            SingleItemOffersRemainingDurationInSeconds: number;
        };
        UpgradeCurrencyStore: {
            UpgradeCurrencyOffers: Store.UpgradeCurrencyOffers;
        };
        BonusStore?: {
            BonusStoreOffers: Array<{
                BonusOfferID: string;
                Offer: Store.Offer;
                DiscountPercent: number;
                DiscountCosts: Store.Currency;
                IsSeen: boolean;
            }>;
            BonusStoreRemainingDurationInSeconds: number;
        };
        AccessoryStore: {
            AccessoryStoreOffers: Array<{
                Offer: Store.Offer;
                ContractID: string;
            }>;
            AccessoryStoreRemainingDurationInSeconds: number;
            StorefrontID: string;
        };
    }
    interface Offers {
        Offers: Array<Store.Offer>;
        UpgradeCurrencyOffers: Store.UpgradeCurrencyOffers;
    }
    interface Entitlements {
        ItemTypeID: string;
        Entitlements: Array<{
            TypeID: string;
            ItemID: string;
        }>;
    }
    interface EntitlementsWithInstance extends Omit<Store.Entitlements, "Entitlements"> {
        Entitlements: Array<{
            TypeID: string;
            ItemID: string;
            InstanceID: string;
        }>;
    }
    interface Agent {
        AgentStore: {
            AgentStoreOffers: Array<{
                AgentID: string;
                StoreOffers: Array<Store.Offer>;
            }>;
            FeaturedAgent: string;
        };
    }
}
export declare class Store extends WebClientService {
    getWallet(subject: string): PromiseResponse<Store.Wallet>;
    getOffers(): PromiseResponse<Store.Offers>;
    getEntitlements(subject: string, itemTypeId: "dd3bf334-87f3-40bd-b043-682a57a8dc3a"): PromiseResponse<Store.EntitlementsWithInstance>;
    getEntitlements(subject: string, itemTypeId: ItemTypeId.ID): PromiseResponse<Store.Entitlements>;
    get StoreFront(): StoreFront;
}
export declare class StoreFront extends WebClientService {
    get(subject: string): PromiseResponse<Store.Storefront>;
    getAgent(): PromiseResponse<Store.Agent>;
    /**
     * @deprecated Please, Contact us if you find out how its works
     */
    revealNightMarketOffers(subject: string): PromiseResponse<any>;
}
